bpgmm Model-Based Clustering Using Baysian PGMM Carries out model-based clustering using parsimonious Gaussian mixture models. MCMC are used for parameter estimation. The RJMCMC is used for model selection.
pgmmRJMCMC(
X,
mInit,
mVec,
qnew,
delta = 2,
ggamma = 2,
burn = 20,
niter = 1000,
constraint = C(0, 0, 0),
dVec = c(1, 1, 1),
sVec = c(1, 1, 1),
Mstep = 0,
Vstep = 0,
SCind = 0
)the observation matrix with size p * m
the number of initial clusters
the range of the number of clusters
the number of factor for a new cluster
scaler hyperparameters
scaler hyperparameters
the number of burn in iterations
the number of iterations
the pgmm initial constraint, a vector of length three with binary entry. For example, c(1,1,1) means the fully constraint model
a vector of hyperparameters with length three, shape parameters for alpha1, alpha2 and bbeta respectively
sVec a vector of hyperparameters with length three, rate parameters for alpha1, alpha2 and bbeta respectively
the indicator of whether do model selection on the number of clusters
the indicator of whether do model selection on variance structures
the indicator of whether use split/combine step in Mstep