The paper represents the eight PGMM covariance structures with three-letter model names. Each letter is either `C` for constrained or `U` for unconstrained. The letters indicate whether the loading matrix is shared across clusters, whether the noise covariance is shared across clusters, and whether the noise covariance is isotropic within clusters.